@@ -1,7 +1,7 @@
 from django.db import models as _models
 from model_utils.models import TimeStampedModel as _TimeStampedModel
 
-from b2_utils.models.enums import Colors, States
+from b2_utils.models.enums import Colors, Operator, OrderedTextChoices, States
 
 __all__ = [
     "Phone",
@@ -9,6 +9,8 @@ __all__ = [
     "Address",
     "States",
     "Colors",
+    "Operator",
+    "OrderedTextChoices",
 ]
 
 
